package cn.iocoder.yudao.module.contract.service;

import cn.iocoder.yudao.module.contract.entity.ContractHistory;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import java.util.List;

/**
 * 签署历史Service接口
 *
 * @author ruoyi
 * @date 2023-07-19
 */
public interface IContractHistoryService
{
    /**
     * 查询签署历史
     *
     * @param id 签署历史主键
     * @return 签署历史
     */
    public ContractHistory selectContractHistoryById(Long id);

    /**
     * 查询签署历史列表
     *
     * @param contractHistory 签署历史
     * @return 签署历史集合
     */
    public IPage<ContractHistory> selectContractHistoryList(Page<ContractHistory> page, ContractHistory contractHistory);

    /**
     * 新增签署历史
     *
     * @param contractHistory 签署历史
     * @return 结果
     */
    public int insertContractHistory(ContractHistory contractHistory);

    /**
     * 修改签署历史
     *
     * @param contractHistory 签署历史
     * @return 结果
     */
    public int updateContractHistory(ContractHistory contractHistory);

    /**
     * 批量删除签署历史
     *
     * @param ids 需要删除的签署历史主键集合
     * @return 结果
     */
    public int deleteContractHistoryByIds(Long[] ids);

    /**
     * 删除签署历史信息
     *
     * @param id 签署历史主键
     * @return 结果
     */
    public int deleteContractHistoryById(Long id);
}
